==> apgl-0.5.9.1.tar.gz: apgl-0.5.9.1/setup.py <==
#!/usr/bin/env python
#The first line is needed for egg files and the second for exes, rpms, tars etc.
from setuptools import setup
#from distutils.core import setup

execfile('apgl/version.py')

#Call either of
#python setup.py bdist_egg
#python setup.py sdist

setup (
  name = 'apgl',
  version = __version__,
  #package_dir={'apgl': 'src/apgl'},
  packages = ['apgl', 'apgl.predictors', 'apgl.predictors.test', 'apgl.predictors.edge', 'apgl.predictors.edge.test', 'apgl.data', 'apgl.features', 'apgl.features.test', 'apgl.graph', 'apgl.graph.test', 'apgl.io', 'apgl.util', 'apgl.util.test', 'apgl.kernel', 'apgl.kernel.test'],

  # Declare your packages' dependencies here, for eg:
  install_requires=['numpy>=1.3.0', 'scipy>=0.7.1'],

  # Fill in these to make your Egg ready for upload to
  # PyPI
  author = 'Charanpal Dhanjal',
  author_email = 'charanpal@gmail.com',

  summary = 'A fast python graph library based on numpy and scipy with some machine learning features.',
  url = 'http://www.somethingaboutme.net/code2.php',
  license = 'GNU Library or Lesser General Public License (LGPL)',
  long_description= 'More details are given on the homepage of this project http://www.somethingaboutme.net/code2.php.',

  # could also include long_description, download_url, classifiers, etc.
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    ],

  keywords=['graph library', 'numpy', 'scipy', 'machine learning'],
  platforms=["OS Independent"],



)

==> apgl-0.6.1.tar.gz: apgl-0.6.1/setup.py <==
#!/usr/bin/env python
#The first line is needed for egg files and the second for exes, rpms, tars etc.
from setuptools import setup
#from distutils.core import setup

execfile('apgl/version.py')

#Call either of
#python setup.py bdist_egg
#python setup.py sdist

setup (
  name = 'apgl',
  version = __version__,
  #package_dir={'apgl': 'src/apgl'},
  packages = ['apgl', 'apgl.generator', 'apgl.generator.test', 'apgl.predictors', 'apgl.predictors.test', 'apgl.predictors.edge', 'apgl.predictors.edge.test', 'apgl.data', 'apgl.features', 'apgl.features.test', 'apgl.graph', 'apgl.graph.test', 'apgl.io', 'apgl.util', 'apgl.util.test', 'apgl.kernel', 'apgl.kernel.test'],

  # Declare your packages' dependencies here, for eg:
  install_requires=['numpy>=1.3.0', 'scipy>=0.7.1'],

  # Fill in these to make your Egg ready for upload to
  # PyPI
  author = 'Charanpal Dhanjal',
  author_email = 'charanpal@gmail.com',

  summary = 'A fast python graph library based on numpy and scipy with some machine learning features.',
  url = 'http://www.somethingaboutme.net/code2.php',
  license = 'GNU Library or Lesser General Public License (LGPL)',
  long_description= 'More details are given on the homepage of this project http://www.somethingaboutme.net/code2.php.',

  # could also include long_description, download_url, classifiers, etc.
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    ],

  keywords=['graph library', 'numpy', 'scipy', 'machine learning'],
  platforms=["OS Independent"],



)
